@@ -17,13 +17,11 @@ class Server:
         if static_dir is not None and static_path is not None:
             # Add static file serving to enable swagger GUI
             caller = getframeinfo(stack()[1][0])
-
             PATH = os.path.abspath(os.path.dirname(caller.filename))
-
-            cherrypy.tree.mount(Static(), '/static', config={
+            cherrypy.tree.mount(Static(), static_path, config={
                 '/': {
                     'tools.staticdir.on': True,
-                    'tools.staticdir.dir': PATH + '/static',
+                    'tools.staticdir.dir': PATH + static_dir,
                     'tools.staticdir.index': 'index.html',
                 }
             })
